### R code from vignette source 'mhw_1a'

###################################################
### code chunk number 1: mhw_1a.Rnw:41-45
###################################################
plot(density(mhw$grain), col="darkblue",
     main="Grain yield, lb. per plot", lwd=1.5)
rug(mhw$grain, col="darkgreen")
grid()


###################################################
### code chunk number 2: mhw_1a.Rnw:58-70
###################################################
plot(ecdf(mhw$grain), pch=1,
     xlab="Mercer & Hall, Grain yield, lb. per plot", 
     ylab="Cumulative proportion of plots",
     main="Empirical CDF",
     sub="Quantiles shown with vertical lines")
q <- quantile(mhw$grain, c(.05, .1, .25, .75, .9, .95))
abline(v=q, lty=2)
abline(v=median(mhw$grain), col="blue")
abline(v=max(mhw$grain), col="green")
abline(v=min(mhw$grain), col="green")
text(q, 0.5, names(q))
rm(q)


###################################################
### code chunk number 3: mhw_1a.Rnw:83-87
###################################################
qqnorm(mhw$grain,
       main="Normal probability plot, grain yields (lb. plot-1)")
qqline(mhw$grain)
grid()


###################################################
### code chunk number 4: mhw_1a.Rnw:106-108
###################################################
mean(mhw$grain)
sd(mhw$grain)


###################################################
### code chunk number 5: mhw_1a.Rnw:117-130
###################################################
res <- 0.1
hist(mhw$grain, breaks=seq(round(min(mhw$grain),1)-res,
              round(max(mhw$grain),1)+res, by=res),
     col="lightblue", border="red", freq=F,
     xlab="Wheat grain yield, lb. per plot",
     main="Mercer & Hall uniformity trial",
     sub="Theoretical distribution (solid), empirical density (dashed)")
grid()
rug(mhw$grain)
x <- seq(min(mhw$grain)-res, max(mhw$grain)+res, by=.01)
lines(x, dnorm(x, mean(mhw$grain), sd(mhw$grain)), col="blue", lty=1, lwd=1.8) 
lines(density(mhw$grain), lty=2, lwd=1.8, col="black")
rm(res, x)


###################################################
### code chunk number 6: mhw_1a.Rnw:135-145
###################################################
plot(density(mhw$grain), col="darkblue",
    main="Grain yield, lb. per plot", lwd=1.5, ylim=c(0,1),
    xlab=paste("Sample mean:",round(mean(mhw$grain), 3),
      "; s.d:", round(sd(mhw$grain),3)))
grid()
rug(mhw$grain)
curve(dnorm(x, mean(mhw$grain), sd(mhw$grain)), 2.5, 6, add=T,
      col="darkred", lwd=1.5)
text(2.5, 0.85, "Empirical", col="darkblue", pos=4)
text(2.5, 0.8, "Theoretical normal", col="darkred", pos=4)


###################################################
### code chunk number 7: mhw_1a.Rnw:150-151
###################################################
shapiro.test(mhw$grain)


###################################################
### code chunk number 8: mhw_1a.Rnw:168-169
###################################################
(t.q13 <- qt(c(.25, .75), length(mhw$grain) - 1))


###################################################
### code chunk number 9: mhw_1a.Rnw:174-175
###################################################
(pe <- mean(mhw$grain) + t.q13 * sd(mhw$grain))


###################################################
### code chunk number 10: mhw_1a.Rnw:180-182
###################################################
rel.error <- (diff(pe)/2) / mean(mhw$grain)
round(100 * rel.error, 2)


###################################################
### code chunk number 11: mhw_1a.Rnw:197-198
###################################################
(yield.ha <- mean(mhw$grain)*500/(0.40469)/(2.2046226))


###################################################
### code chunk number 12: mhw_1a.Rnw:208-209
###################################################
round(yield.ha * rel.error, 2)


###################################################
### code chunk number 13: mhw_1a.Rnw:213-216
###################################################
ans.re <- rel.error
ans.yld <- yield.ha
ans.yld.pe <- round(yield.ha * rel.error, 2)


###################################################
### code chunk number 14: mhw_1a.Rnw:221-222
###################################################
rm(t.q13, pe, rel.error, yield.ha)


###################################################
### code chunk number 15: mhw_1a.Rnw:257-258
###################################################
rm(ans.re, ans.yld, ans.yld.pe)


###################################################
### code chunk number 16: mhw_1a.Rnw:268-277
###################################################
plot(mhw$straw ~ mhw$grain,
     xlab="Grain yield (lb. plot-1)",
     ylab="Straw yield (lb. plot-1)",
     pch=20, col="darkblue", cex=1.2,
     sub="Medians shown with red dashed lines") 
title(main="Straw vs. grain yields, Mercer-Hall experiment")
grid()
abline(v=median(mhw$grain), lty=2, col="red")
abline(h=median(mhw$straw), lty=2, col="red")


###################################################
### code chunk number 17: mhw_1a.Rnw:331-332
###################################################
colMeans(mhw[,c("grain","straw")])


###################################################
### code chunk number 18: mhw_1a.Rnw:337-338
###################################################
var(mhw[,c("grain","straw")])


###################################################
### code chunk number 19: mhw_1a.Rnw:347-352
###################################################
require(MASS)
sim.sample <- mvrnorm(length(mhw$grain), mu=colMeans(mhw[,c("grain","straw")]), Sigma=var(mhw[,c("grain","straw")]))
head(sim.sample)
summary(sim.sample)
summary(mhw[,c("grain", "straw")])


###################################################
### code chunk number 20: mhw_1a.Rnw:358-370
###################################################
par(mfrow=c(2,2))
grain.lim = c(min(sim.sample[,"grain"], mhw$grain), max(sim.sample[,"grain"], mhw$grain)) 
straw.lim = c(min(sim.sample[,"straw"], mhw$straw), max(sim.sample[,"straw"], mhw$straw)) 
hist(mhw$grain, xlim=grain.lim, main="Grain (actual)", col="lightyellow",
     breaks=seq(grain.lim[1],grain.lim[2], length=17))
hist(sim.sample[,"grain"],xlim=grain.lim, main="Grain (simulated)", col="cornsilk",
     breaks=seq(grain.lim[1],grain.lim[2], length=17))
hist(mhw$straw, xlim=straw.lim, main="Straw (actual)", col="lightblue",
     breaks=seq(straw.lim[1],straw.lim[2], length=17))
hist(sim.sample[,"straw"],xlim=straw.lim, main="Straw (simulated)", col="lavender",
          breaks=seq(straw.lim[1],straw.lim[2], length=17))
par(mfrow=c(1,1))


###################################################
### code chunk number 21: mhw_1a.Rnw:381-389
###################################################
par(mfrow=c(1,2))
plot(sim.sample, main="Simulated straw vs. grain yields", xlab="Grain (lb. plot-1)", ylab="Straw (lb. plot-1)", xlim=grain.lim, ylim=straw.lim, pch=20, col="blue")  
abline(v=median(sim.sample[,1]), lty=2, col="red")
abline(h=median(sim.sample[,2]), lty=2, col="red")
plot(mhw$grain, mhw$straw, main="Actual straw vs. grain yields", xlab="Grain (lb. plot-1)", ylab="Straw (lb. plot-1)", xlim=grain.lim, ylim=straw.lim, pch=20, col="black")  
abline(v=median(mhw$grain), lty=2, col="red")
abline(h=median(mhw$straw), lty=2, col="red")
par(mfrow=c(1,1))


###################################################
### code chunk number 22: mhw_1a.Rnw:398-399
###################################################
rm(sim.sample, grain.lim, straw.lim)


###################################################
### code chunk number 23: mhw_1a.Rnw:414-416
###################################################
cor(mhw$grain, mhw$straw)
cor.test(mhw$grain, mhw$straw)


###################################################
### code chunk number 24: mhw_1a.Rnw:587-590
###################################################
model.straw.grain <- lm(straw ~ grain, data=mhw)
summary(model.straw.grain)
coefficients(model.straw.grain)


###################################################
### code chunk number 25: mhw_1a.Rnw:622-628
###################################################
plot(straw ~ grain, data=mhw)
title("Straw yield predicted by grain yield")
abline(model.straw.grain)
grid()
text(4.5, 4.5, paste("slope:",
                     round(coefficients(model.straw.grain)[2], 2)))


###################################################
### code chunk number 26: mhw_1a.Rnw:654-656
###################################################
hist(residuals(model.straw.grain),
     main="Residuals from straw vs.\ grain linear model")


###################################################
### code chunk number 27: mhw_1a.Rnw:659-663
###################################################
qqnorm(residuals(model.straw.grain),
       main="Residuals from straw vs.\ grain linear model")
qqline(residuals(model.straw.grain))
summary(residuals(model.straw.grain))


###################################################
### code chunk number 28: mhw_1a.Rnw:672-673
###################################################
shapiro.test(residuals(model.straw.grain))


###################################################
### code chunk number 29: mhw_1a.Rnw:686-702
###################################################
lim <- c(min(fitted(model.straw.grain), mhw$straw),
         max(fitted(model.straw.grain), mhw$straw))
plot(fitted(model.straw.grain), mhw$straw,
     xlab="Modelled", ylab="Actual", asp=1,
     xlim=lim, ylim=lim, pch=20,
     col=ifelse(
       (abs(fitted(model.straw.grain) - mhw$straw) < 1),
       "gray",
       ifelse(fitted(model.straw.grain) < mhw$straw, "blue","red")),
     cex=ifelse(
       (abs(fitted(model.straw.grain) - mhw$straw) < 1),1,1.3)
)
title("Actual vs. modelled straw yields")
grid()
abline(0,1)
rm(lim)


###################################################
### code chunk number 30: mhw_1a.Rnw:717-719
###################################################
which.high.res <- which(abs(residuals(model.straw.grain)) > 1.8)
sort(residuals(model.straw.grain)[which.high.res])


###################################################
### code chunk number 31: mhw_1a.Rnw:724-727
###################################################
high.res <- mhw[which.high.res,]
high.res[order(high.res$gsr),]
rm(which.high.res, high.res)


###################################################
### code chunk number 32: mhw_1a.Rnw:750-751
###################################################
plot(model.straw.grain, which=1)


###################################################
### code chunk number 33: mhw_1a.Rnw:766-767
###################################################
plot(model.straw.grain, which=5)


###################################################
### code chunk number 34: mhw_1a.Rnw:774-775
###################################################
plot(model.straw.grain, which=6, id.n=10)


###################################################
### code chunk number 35: mhw_1a.Rnw:827-833
###################################################
t1 <- mean(mhw$grain); t2 <- sd(mhw$grain);
p.frame <- data.frame(grain=seq(t1-2*t2, t1+2*t2, t2))
predict(model.straw.grain, newdata=p.frame,
        interval="confidence", level=0.95)
predict(model.straw.grain, newdata=p.frame,
        interval="prediction", level=0.95)


###################################################
### code chunk number 36: mhw_1a.Rnw:848-861
###################################################
p.frame <- data.frame(grain=seq(from=2,to=6,by=0.1))
pred.c <- predict(model.straw.grain, newdata=p.frame, interval="confidence", level=0.95)
pred.p <- predict(model.straw.grain, newdata=p.frame, interval="prediction", level=0.95)
plot(straw ~ grain, data=mhw, pch=20)
title(main="Straw yield predicted by grain yield", sub="Prediction (blue) and confidence (red) intervals")
abline(model.straw.grain)
grid()
lines(p.frame$grain, pred.c[, "lwr"], col = 2, lwd = 1.5)
lines(p.frame$grain, pred.c[, "upr"], col = 2, lwd = 1.5)
lines(p.frame$grain, pred.p[, "lwr"], col = 4, lwd = 1.5)
lines(p.frame$grain, pred.p[, "upr"], col = 4, lwd = 1.5)
points(mean(mhw$grain),mean(mhw$straw),pch=23,cex=2, bg="red")
abline(h=mean(mhw$straw), lty=2); abline(v=mean(mhw$grain), lty=2)


###################################################
### code chunk number 37: mhw_1a.Rnw:874-875
###################################################
rm(t1,t2,p.frame,pred.c,pred.p)


###################################################
### code chunk number 38: mhw_1a.Rnw:887-890
###################################################
model.grain.straw <- lm(grain ~ straw, data=mhw)
summary(model.grain.straw)
summary(model.straw.grain)


###################################################
### code chunk number 39: mhw_1a.Rnw:903-905
###################################################
coefficients(model.straw.grain)["grain"]
1/coefficients(model.grain.straw)["straw"]


###################################################
### code chunk number 40: mhw_1a.Rnw:920-927
###################################################
plot(straw ~ grain, pch=1, main="Mercer-Hall wheat yields", xlab="grain (lb. plot-1)", ylab="straw (lb. plot-1)", data=mhw)
title(sub="straw vs. grain: solid; grain vs. straw: dashed")
abline(model.straw.grain)
beta <- coefficients(model.grain.straw)
abline(-beta["(Intercept)"]/beta["straw"]  , 1/beta["straw"], lty=2)
grid()
rm(beta)


###################################################
### code chunk number 41: mhw_1a.Rnw:991-992
###################################################
var(mhw$straw)/var(mhw$grain)


###################################################
### code chunk number 42: mhw_1a.Rnw:1019-1024
###################################################
struct.beta <- function(y, x, lambda) {
  a <- var(y)-lambda*var(x);
  c <- var(x,y);
  return((a + sqrt(a^2 + 4 * lambda * c^2))/(2*c))
}


###################################################
### code chunk number 43: mhw_1a.Rnw:1038-1044
###################################################
print(paste("Forward:", round(coefficients(model.straw.grain)["grain"],4)))
print(paste("Proportional:", round(struct.beta(mhw$straw,mhw$grain,var(mhw$straw)/var(mhw$grain)),4)))
print(paste("Inverse proportional:", round(1/struct.beta(mhw$grain,mhw$straw,var(mhw$grain)/var(mhw$straw)),4)))
print(paste("Orthogonal:", round(struct.beta(mhw$straw,mhw$grain,1),4)))
print(paste("Inverse orthogonal:", round(1/struct.beta(mhw$grain,mhw$straw,1),4)))
print(paste("Reverse:", round(1/coefficients(model.grain.straw)["straw"],4)))


###################################################
### code chunk number 44: mhw_1a.Rnw:1060-1088
###################################################
plot(straw ~ grain, main="Mercer-Hall wheat yields",
     sub="Regression slopes", xlab="grain (lb. plot-1)",
     ylab="straw (lb. plot-1)", data=mhw)
abline(model.straw.grain, col="blue")
beta <- coefficients(model.grain.straw)
abline(-beta["(Intercept)"]/beta["straw"]  , 1/beta["straw"],
       lty=2, col="green")
beta <- struct.beta(mhw$straw, mhw$grain, 1)
abline(mean(mhw$straw)-beta*mean(mhw$grain), beta, lty=3, col="red")
beta <- struct.beta(mhw$straw, mhw$grain,var(mhw$straw)/var(mhw$grain))
abline(mean(mhw$straw)-beta*mean(mhw$grain), beta, lty=4, col="brown")
lines(c(4,4.5),c(5,5), lty=1, col="blue") 
lines(c(4,4.5),c(4.4,4.4), lty=4, col="brown") 
lines(c(4,4.5),c(4.6,4.6), lty=3, col="red") 
lines(c(4,4.5),c(4.8,4.8), lty=2, col="green") 
grid()
text(4.5,5,paste("Forward:",
             round(coefficients(model.straw.grain)["grain"],4)),
     col="blue", pos=4)
text(4.5,4.4,paste("Proportional:",
round(struct.beta(mhw$straw,mhw$grain,var(mhw$straw)/var(mhw$grain)),4)),
     col="brown", pos=4)
text(4.5,4.6, paste("Orthogonal:",
                round(struct.beta(mhw$straw,mhw$grain,1),4)),
     col="red", pos=4)
text(4.5,4.8,paste("Reverse:",
               round(1/coefficients(model.grain.straw)["straw"],4)),
     col="green", pos=4)


###################################################
### code chunk number 45: mhw_1a.Rnw:1157-1159
###################################################
model.straw.grain.0 <- lm(straw ~ grain - 1, data=mhw)
summary(model.straw.grain.0)


###################################################
### code chunk number 46: show-with
###################################################
mean(mhw$grain)
with(mhw, mean(grain))


###################################################
### code chunk number 47: mhw_1a.Rnw:1189-1211
###################################################
with(mhw, 
     plot(straw ~ grain, main="Mercer-Hall wheat yields",
          xlab="grain (lb. plot-1)", ylab="straw (lb. plot-1)",
          xlim=c(0,ceiling(max(grain))),
          ylim=c(0, ceiling(max(straw))), cex=0.8))
abline(model.straw.grain, col="blue")
abline(model.straw.grain.0, col="red")
grid()
text(4.5,4, paste("    With:",
             round(coefficients(model.straw.grain)["grain"],2)),
     col="blue", pos=4)
text(4.5,3.4,paste("Without:",
              round(coefficients(model.straw.grain.0)["grain"],2)),
     col="red", pos=4)
abline(v=mean(mhw$grain), col="darkgray", lty=2)
abline(h=mean(mhw$straw), col="darkgray", lty=2)
points(mean(mhw$grain), mean(mhw$straw), cex=2, pch=23, bg="red")
abline(h=coefficients(model.straw.grain)["(Intercept)"],
       col="darkgray", lty=2)
text(1,1,paste("Intercept:",
          round(coefficients(model.straw.grain)["(Intercept)"],2)),
     col="blue", pos=4)


###################################################
### code chunk number 48: mhw_1a.Rnw:1219-1221
###################################################
mean(residuals(model.straw.grain.0))
mean(residuals(model.straw.grain))


###################################################
### code chunk number 49: mhw_1a.Rnw:1248-1255
###################################################
(TSS <- sum((mhw$straw-mean(mhw$straw))^2))
(TSS0 <- sum(mhw$straw^2))
(RSS <- sum(residuals(model.straw.grain)^2))
(RSS0 <- sum(residuals(model.straw.grain.0)^2))
(R2 <- 1 - (RSS/TSS))     
(R20 <- 1 - (RSS0/TSS0))  
rm(TSS, TSS0, RSS, RSS0, R2, R20)


###################################################
### code chunk number 50: mhw_1a.Rnw:1263-1265
###################################################
summary(model.straw.grain.0)$adj.r.squared
summary(model.straw.grain)$adj.r.squared


###################################################
### code chunk number 51: mhw_1a.Rnw:1277-1279
###################################################
sqrt(sum(residuals(model.straw.grain)^2)/(length(mhw$straw)))
sqrt(sum(residuals(model.straw.grain.0)^2)/(length(mhw$straw)))


###################################################
### code chunk number 52: add-in-north
###################################################
mhw <- cbind(mhw, in.north = (mhw$r < 11))
str(mhw)


###################################################
### code chunk number 53: mhw_1a.Rnw:1446-1447
###################################################
summary(mhw$in.north)


###################################################
### code chunk number 54: mhw_1a.Rnw:1456-1464
###################################################
   # plot halves in appropriate colours
with(mhw,
     plot(c, r, col=ifelse(in.north,"blue","darkslategrey"), 
          cex=1.3*straw/max(straw), pch=1,
          xlab="Column", ylab="Row", ylim=c(20,1),
          sub="North: blue; South: gray"))
title(main="Postplot of straw yields, coded by field half")
abline(h=10.5, lty=2)


###################################################
### code chunk number 55: mhw_1a.Rnw:1488-1496
###################################################
par(mfrow=c(3,1))
boxplot(grain ~ in.north, names=c("S", "N"),
        main="Grain yield", horizontal=T, data=mhw)
boxplot(straw ~ in.north, names=c("S", "N"),
        main="Straw yield", horizontal=T, data=mhw)
boxplot(gsr ~ in.north, names=c("S", "N"),
        main="Grain/straw ratio", horizontal=T, data=mhw)
par(mfrow=c(1,1))


###################################################
### code chunk number 56: mhw_1a.Rnw:1511-1517
###################################################
with(mhw, by(grain, in.north, summary))
with(mhw,      by(straw, in.north, summary))
with(mhw,      by(gsr, in.north, summary))
with(mhw,      by(grain, in.north, var))
with(mhw,      by(straw, in.north, var))
with(mhw,      by(gsr, in.north, var))


###################################################
### code chunk number 57: mhw_1a.Rnw:1536-1538
###################################################
   # compare the means with a t-test
with(mhw, t.test(straw[in.north], straw[!in.north]))


###################################################
### code chunk number 58: mhw_1a.Rnw:1556-1558
###################################################
model.straw.ns <- lm(straw ~ in.north, data=mhw)
summary(model.straw.ns)


###################################################
### code chunk number 59: mhw_1a.Rnw:1567-1568
###################################################
anova(model.straw.ns)


###################################################
### code chunk number 60: mhw_1a.Rnw:1573-1577
###################################################
qqnorm(residuals(model.straw.ns),
       main="Residuals from one-way ANOVA",
       sub="Straw yield vs. field half")
qqline(residuals(model.straw.ns))


###################################################
### code chunk number 61: mhw_1a.Rnw:1637-1639
###################################################
quantile(mhw$grain, p=0.01, type=5)
mean(sort(mhw$grain)[5:6])


###################################################
### code chunk number 62: mhw_1a.Rnw:1669-1670
###################################################
quantile(mhw$grain, p=0.01, type=5)


###################################################
### code chunk number 63: mhw_1a.Rnw:1681-1685
###################################################
boot.q01 <- function(data, indices){
	obs <- data[indices,]
	return(quantile(obs$grain, p=0.01, type=5))
}


###################################################
### code chunk number 64: mhw_1a.Rnw:1698-1701
###################################################
require(boot)
b.q01 <- boot(mhw, boot.q01, R=1024)
print(b.q01)


###################################################
### code chunk number 65: mhw_1a.Rnw:1718-1719
###################################################
plot(b.q01)


###################################################
### code chunk number 66: mhw_1a.Rnw:1761-1763
###################################################
mean(b.q01$t)
b.q01$t0


###################################################
### code chunk number 67: mhw_1a.Rnw:1772-1773
###################################################
(b.q01.ci <- boot.ci(b.q01, conf = 0.95, type=c("norm","basic")))


###################################################
### code chunk number 68: mhw_1a.Rnw:1792-1797 (eval = FALSE)
###################################################
## struct.beta <- function(y, x, lambda) {
##   a <- var(y)-lambda*var(x);
##   c <- var(x,y);
##   return((a + sqrt(a^2 + 4 * lambda * c^2))/(2*c))
## }


###################################################
### code chunk number 69: mhw_1a.Rnw:1802-1804 (eval = FALSE)
###################################################
## beta <- struct.beta(straw,grain,var(straw)/var(grain))
## alpha <- mean(straw)-beta*mean(grain)


###################################################
### code chunk number 70: mhw_1a.Rnw:1815-1822
###################################################
boot.sr <- function (data, indices) {
	obs <- data[indices,]
        beta <- struct.beta(obs$straw,obs$grain,
                            var(obs$straw)/var(obs$grain))
        alpha <- mean(obs$straw)-beta*mean(obs$grain)
	return(c(beta, alpha))
}


###################################################
### code chunk number 71: mhw_1a.Rnw:1827-1829
###################################################
b.sr <- boot(mhw, boot.sr, R=1024)
print(b.sr)


###################################################
### code chunk number 72: mhw_1a.Rnw:1835-1836
###################################################
plot(b.sr, index=1)


###################################################
### code chunk number 73: mhw_1a.Rnw:1843-1844
###################################################
plot(b.sr, index=2)


###################################################
### code chunk number 74: mhw_1a.Rnw:1858-1862
###################################################
mean(b.sr$t[,1])
(b.sr.ci <- boot.ci(b.sr, conf = 0.95, type=c("norm","basic"), index=1))
mean(b.sr$t[,2])
(b.sr.ci <- boot.ci(b.sr, conf = 0.95, type=c("norm","basic"), index=2))


###################################################
### code chunk number 75: mhw_1a.Rnw:1874-1877
###################################################
b.corr <- function(data,indices) { 	obs <- data[indices,]; return(cor(obs$grain, obs$straw)) }
boot.corr <- boot(mhw, b.corr, R=1024)
boot.corr.ci <- boot.ci(boot.corr, conf=0.95, type="basic")


###################################################
### code chunk number 76: mhw_1a.Rnw:1883-1884
###################################################
plot(boot.corr)


###################################################
### code chunk number 77: mhw_1a.Rnw:1937-1940
###################################################
rm(model.grain.straw)
rm(boot.q01, b.q01, b.q01.ci, boot.sr, b.sr, b.sr.ci)
detach(package:boot)


###################################################
### code chunk number 78: mhw_1a.Rnw:1943-1944
###################################################
rm(boot.corr, b.corr, boot.corr.ci)


